==> haskell-hakyll-4.8.3.1-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hakyll.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hakyll
version: 4.8.3.1
id: hakyll-4.8.3.1-B7bB6wDEHwNARvqqZL9LA0
key: hakyll-4.8.3.1-B7bB6wDEHwNARvqqZL9LA0
license: BSD3
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
homepage: http://jaspervdj.be/hakyll
synopsis: A static website compiler library
description:
    Hakyll is a static website compiler library. It provides you with the tools to
    create a simple or advanced static website using a Haskell DSL and formats
    such as markdown or RST. You can find more information, including a tutorial,
    on the website:
    .
    * <http://jaspervdj.be/hakyll>
    .
    If you seek assistance, there'\''s:
    .
    * A google group: <http://groups.google.com/group/hakyll>
    .
    * An IRC channel, @#hakyll@ on freenode
    .
    Additionally, there'\''s the Haddock documentation in the different modules,
    meant as a reference.
category: Web
author: Jasper Van der Jeugt <m@jaspervdj.be>
exposed: True
exposed-modules:
    Hakyll Hakyll.Core.Compiler Hakyll.Core.Configuration
    Hakyll.Core.Dependencies Hakyll.Core.File Hakyll.Core.Identifier
    Hakyll.Core.Identifier.Pattern Hakyll.Core.Item
    Hakyll.Core.Metadata Hakyll.Core.Routes Hakyll.Core.Rules
    Hakyll.Core.UnixFilter Hakyll.Core.Util.String Hakyll.Core.Writable
    Hakyll.Main Hakyll.Web.CompressCss Hakyll.Web.Feed Hakyll.Web.Html
    Hakyll.Web.Html.RelativizeUrls Hakyll.Web.Pandoc
    Hakyll.Web.Pandoc.Biblio Hakyll.Web.Pandoc.FileType Hakyll.Web.Tags
    Hakyll.Web.Paginate Hakyll.Web.Template
    Hakyll.Web.Template.Internal Hakyll.Web.Template.Context
    Hakyll.Web.Template.List
hidden-modules: Data.List.Extended Data.Yaml.Extended Hakyll.Check
                Hakyll.Commands Hakyll.Core.Compiler.Internal
                Hakyll.Core.Compiler.Require Hakyll.Core.Item.SomeItem
                Hakyll.Core.Logger Hakyll.Core.Provider
                Hakyll.Core.Provider.Internal Hakyll.Core.Provider.Metadata
                Hakyll.Core.Provider.MetadataCache Hakyll.Core.Rules.Internal
                Hakyll.Core.Runtime Hakyll.Core.Store Hakyll.Core.Util.File
                Hakyll.Core.Util.Parser Hakyll.Web.Pandoc.Binary Paths_hakyll
abi: 5a4231f64b149289a141312ec9773c6a
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hakyll-4.8.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/hakyll-4.8.3.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/hakyll-4.8.3.1
hs-libraries: HShakyll-4.8.3.1-B7bB6wDEHwNARvqqZL9LA0
depends:
    base-4.9.0.0 binary-0.8.3.0
    blaze-html-0.8.1.1-BhhXJch8Gg8D1ETUvb8oFp
    blaze-markup-0.7.0.3-6iLNhqMnSkpL7LEeNEW58d bytestring-0.10.8.1
    cmdargs-0.10.14-CJAOGiZkh3OIu1n8WPqRj9 containers-0.5.7.1
    cryptohash-0.11.9-92gpZTo1QU29KRDMREFkoR
    data-default-0.7.1-JFxCZPlwLrgBdoJyXvU7p7 deepseq-1.4.2.0
    directory-1.2.6.2 filepath-1.4.1.0
    http-conduit-2.1.10.1-DrS3Vpny37J3EYy8WwtAWK
    http-types-0.9.1-COSfHHdOet5Sq6KAE7lWN
    lrucache-1.2.0.0-KWUHhqZGhlfpESfDWIYIY
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    network-2.6.2.1-Li0aefQhyJzUSpQ0fLiXL
    network-uri-2.6.1.0-8yR4gjnzE4eDGhJR7PHfVJ
    pandoc-1.17.1-Iovmcf8z5OJ4QYvtzuEHYD
    pandoc-citeproc-0.10-AOdsjx9cjrBFdUscUtaxg5
    parsec-3.1.11-IYEP8Lv1S9x5FeUQxGPDBY process-1.4.2.0
    random-1.1-54KmMHXjttlERYcr1mvsAe
    regex-base-0.93.2-4lnOy3Rb1yfISFVEXVfJuH
    regex-tdfa-1.2.2-LZ7BXF6FmWOD2v5FByhfgx
    resourcet-1.1.7.4-5MzcrbA8GQD6CRuZwV7nMM
    scientific-0.3.4.7-5pvfIBiHUcSGJtkaWTYnEJ
    tagsoup-0.14-Cyor6HaGaUK6jsf16bXCqB
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    time-locale-compat-0.1.1.1-HUIdYN9kpfnDYb4ETBn6RW
    unordered-containers-0.2.7.1-6Q3w38ZivLTB9nLFgf8RUI
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
    yaml-0.8.17.2-B7CxPmK5AsvA6OoLT3DouV
haddock-interfaces: /usr/share/doc/haskell-hakyll/html/hakyll.haddock
haddock-html: /usr/share/doc/haskell-hakyll/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hakyll-4.8.3.2-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hakyll.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hakyll
version: 4.8.3.2
id: hakyll-4.8.3.2-7J0c00uYiwH9JTBQaswz6Y
key: hakyll-4.8.3.2-7J0c00uYiwH9JTBQaswz6Y
license: BSD3
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
homepage: http://jaspervdj.be/hakyll
synopsis: A static website compiler library
description:
    Hakyll is a static website compiler library. It provides you with the tools to
    create a simple or advanced static website using a Haskell DSL and formats
    such as markdown or RST. You can find more information, including a tutorial,
    on the website:
    .
    * <http://jaspervdj.be/hakyll>
    .
    If you seek assistance, there'\''s:
    .
    * A google group: <http://groups.google.com/group/hakyll>
    .
    * An IRC channel, @#hakyll@ on freenode
    .
    Additionally, there'\''s the Haddock documentation in the different modules,
    meant as a reference.
category: Web
author: Jasper Van der Jeugt <m@jaspervdj.be>
exposed: True
exposed-modules:
    Hakyll Hakyll.Core.Compiler Hakyll.Core.Configuration
    Hakyll.Core.Dependencies Hakyll.Core.File Hakyll.Core.Identifier
    Hakyll.Core.Identifier.Pattern Hakyll.Core.Item
    Hakyll.Core.Metadata Hakyll.Core.Routes Hakyll.Core.Rules
    Hakyll.Core.UnixFilter Hakyll.Core.Util.String Hakyll.Core.Writable
    Hakyll.Main Hakyll.Web.CompressCss Hakyll.Web.Feed Hakyll.Web.Html
    Hakyll.Web.Html.RelativizeUrls Hakyll.Web.Pandoc
    Hakyll.Web.Pandoc.Biblio Hakyll.Web.Pandoc.FileType Hakyll.Web.Tags
    Hakyll.Web.Paginate Hakyll.Web.Template
    Hakyll.Web.Template.Internal Hakyll.Web.Template.Context
    Hakyll.Web.Template.List
hidden-modules: Data.List.Extended Data.Yaml.Extended Hakyll.Check
                Hakyll.Commands Hakyll.Core.Compiler.Internal
                Hakyll.Core.Compiler.Require Hakyll.Core.Item.SomeItem
                Hakyll.Core.Logger Hakyll.Core.Provider
                Hakyll.Core.Provider.Internal Hakyll.Core.Provider.Metadata
                Hakyll.Core.Provider.MetadataCache Hakyll.Core.Rules.Internal
                Hakyll.Core.Runtime Hakyll.Core.Store Hakyll.Core.Util.File
                Hakyll.Core.Util.Parser Hakyll.Web.Pandoc.Binary Paths_hakyll
abi: 03a8baea4eed7296ddaf69974c50f214
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hakyll-4.8.3.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/hakyll-4.8.3.2
data-dir: /usr/share/arm-linux-ghc-8.0.1/hakyll-4.8.3.2
hs-libraries: HShakyll-4.8.3.2-7J0c00uYiwH9JTBQaswz6Y
depends:
    base-4.9.0.0 binary-0.8.3.0
    blaze-html-0.8.1.1-BhhXJch8Gg8D1ETUvb8oFp
    blaze-markup-0.7.0.3-6iLNhqMnSkpL7LEeNEW58d bytestring-0.10.8.1
    cmdargs-0.10.14-CJAOGiZkh3OIu1n8WPqRj9 containers-0.5.7.1
    cryptohash-0.11.9-92gpZTo1QU29KRDMREFkoR
    data-default-0.7.1-JFxCZPlwLrgBdoJyXvU7p7 deepseq-1.4.2.0
    directory-1.2.6.2 filepath-1.4.1.0
    http-conduit-2.1.10.1-DrS3Vpny37J3EYy8WwtAWK
    http-types-0.9.1-COSfHHdOet5Sq6KAE7lWN
    lrucache-1.2.0.0-H8tP3vowTxbEA5UTTpKBQc
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    network-2.6.2.1-Li0aefQhyJzUSpQ0fLiXL
    network-uri-2.6.1.0-8yR4gjnzE4eDGhJR7PHfVJ
    pandoc-1.17.1-678uzJ1Xl14DWkSUljInDJ
    pandoc-citeproc-0.10-B8yXDcPwq6O2DjBwvM0aXR
    parsec-3.1.11-IYEP8Lv1S9x5FeUQxGPDBY process-1.4.2.0
    random-1.1-54KmMHXjttlERYcr1mvsAe
    regex-base-0.93.2-4lnOy3Rb1yfISFVEXVfJuH
    regex-tdfa-1.2.2-LZ7BXF6FmWOD2v5FByhfgx
    resourcet-1.1.7.4-5MzcrbA8GQD6CRuZwV7nMM
    scientific-0.3.4.7-5pvfIBiHUcSGJtkaWTYnEJ
    tagsoup-0.14-Cyor6HaGaUK6jsf16bXCqB
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    time-locale-compat-0.1.1.1-HUIdYN9kpfnDYb4ETBn6RW
    unordered-containers-0.2.7.1-6Q3w38ZivLTB9nLFgf8RUI
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
    yaml-0.8.18-Y12YVgvasqBpVI5Pdbd4h
haddock-interfaces: /usr/share/doc/haskell-hakyll/html/hakyll.haddock
haddock-html: /usr/share/doc/haskell-hakyll/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
